#
# spec file for package flacon
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           flacon
Version:        1.0.1
Release:        1.2
License:        LGPL-2.1+
Summary:        Split Compressed Audio CD Image to Tracks
Url:            http://flacon.github.io/
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Source0:        https://github.com/flacon/flacon/archive/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(uchardet)
# not actually needed for build, but in order to make the build fail
# if the runtime dependencies are not available in the repository:
BuildRequires:  faac
BuildRequires:  flac
BuildRequires:  lame
BuildRequires:  mac
BuildRequires:  shntool
BuildRequires:  ttaenc
BuildRequires:  vorbis-tools
BuildRequires:  wavpack
Requires:       faac
Requires:       flac
Requires:       lame
Requires:       mac
Requires:       shntool
Requires:       ttaenc
Requires:       vorbis-tools
Requires:       wavpack
Recommends:     %{name}-lang
Recommends:     mp3gain
Recommends:     vorbisgain
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Flacon extracts individual tracks from one big audio file containing
the entire album of music and saves them as separate audio files. To do
this, it uses information from the appropriate CUE file. Besides, Flacon
makes it possible to conveniently revise or specify tags both for all
tracks at once or for each tag separately.

%lang_package

%prep
%setup -q

%build
mkdir build
cd build
cmake .. \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_CXX_FLAGS="%{optflags}"
make %{?_smp_mflags} VERBOSE=1

%install
pushd build
%make_install
popd
%find_lang %{name} --with-qt
%suse_update_desktop_file %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/translations/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*
%doc %{_mandir}/man?/*

%files lang -f %{name}.lang
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}/translations/

%changelog
* Mon Aug 25 2014 lazy.kent@opensuse.org
- Update to 1.0.1.
  * Improved translators list in the About dialog.
  * Translations updated.
* Mon Jul 21 2014 lazy.kent@opensuse.org
- Update to 1.0.0.
  * Added a set of pre defined patterns and history for them.
  * Added encoding support for Windows 1250, Windows 1252-1258.
  * Fix: When there is a slash in the cue file, Flacon creates a
    sub directory for each value after the slash.
  * Improved support for high DPI displays.
  * Improved parsing of nonstandard time in CUE indexes, for
    example MM:SS.mmm.
* Sat Mar  8 2014 lazy.kent@opensuse.org
- Update to 0.9.4.
  * Fix: the desktop file was untranslated.
  * Translations updated.
* Wed Dec 25 2013 lazy.kent@opensuse.org
- Update to 0.9.3.
  * Update translations.
- Drop flacon-qt_version_check.patch (fixed upstream).
* Sun Oct 27 2013 lazy.kent@opensuse.org
- Update to 0.9.2.
  * Fix regression: Drag'n'drop support.
  * Fix: Encoding interrupted if output path contains brackets.
  * Small GUI improvements.
  * Updated and new translations.
- Update flacon-qt_version_check.patch.
- Correct URLs.
* Sat Oct 19 2013 lazy.kent@opensuse.org
- Add flacon-0.9.1-qt_version_check.patch: fix compile with Qt <
  4.8.0.
* Mon Oct 14 2013 lazy.kent@opensuse.org
- Update to 0.9.1.
  * Fix incorrect names of the icons.
- Changes in 0.9.0.
  * The program rewritten on C++.
  * In order to make Flacon a bit more user friendly, some of the
    dialogs have been rephrased.
- Change the program URL.
- Correct License tag.
- Add docs.
* Fri May 24 2013 lazy.kent@opensuse.org
- Update to 0.8.0.
  * Optional patterns in the output file template.
  * Added generation of the pertrack CUE file in the output dir.
  * Process CUE tags: CATALOG, CDTEXTFILE, FLAGS, ISRC, SONGWRITER.
  * Updated and new translations.
- Remove mp3gain and vorbisgain from BuildRequires. They aren't
  hard dependencies.
* Fri Aug 17 2012 lazy.kent@opensuse.org
- Update to 0.7.2.
  * Fix. The program sometimes crashes when parsing incorrect CDDB
    data.
  * Fix. When bulk coding, the program could not create the
    directories.
  * Improved translations detection.
* Sat Aug  4 2012 lazy.kent@opensuse.org
- Update to 0.7.1.
  * Fix in the Makefile.
  * Simplified Chinese and Traditional Chinese translations.
* Fri Aug  3 2012 lazy.kent@opensuse.org
- Update to 0.7.0.
  * Added automatic character set detection for CUE files.
  * New translations.
  * Flacon uses www.transifex.comt for the translation.
- Split off language package.
- Requires: python-chardet.
- Add desktop_database_post/un macros.
- Remove check for unsupported openSUSE versions.
* Mon Feb 13 2012 lazy.kent@opensuse.org
- Update to 0.6.1.
  * Fix in pl_PL translation.
  * Fixed IOError: Interrupted system call.
  * Improved translation search.
* Thu Dec  1 2011 lazy.kent@opensuse.org
- Update to 0.6.0.
  * AAC encoder added (requires faac).
  * French and French Canadian translations.
  * Improved error and warning handling. More info in the messages.
  * Many text improvements.
  * Download-progress and warning icons more visible.
  * Another small GUI improvements and internal code refactoring.
- Corrected License tag.
- Use full URL as a source.
- Added icon_theme_cache_post/un macros.
- Spec clean up.
* Sun May  8 2011 lazy.kent@opensuse.org
- Update to 0.5.7
  * Added ISO-8859-XX codepages.
  * Fixed: Incorrect CD-quality check.
  * Fixed: Incorrect translation of the converter error
    messages.
  * The Makefile checks if pyuic4 exists.
* Wed Mar  2 2011 lazy.kent@opensuse.org
- Moved to Packman.
- Removed specific pyton-sip version dependency for oS < 11.2.
- Requires ttaenc.
* Sat Feb 12 2011 lazy.kent@opensuse.org
- Build requires libqt4-devel and python-qt4 for oS 11.1.
* Fri Feb 11 2011 lazy.kent@opensuse.org
- Update to 0.5.6
  * Fix: Configure dialog->programs->"search program file" caused
    an error.
  * Add: Icon names compatible with KDE3 are added.
- Build requires python-qt4-devel to compile locales.
* Thu Feb 10 2011 lazy.kent@opensuse.org
- Update to 0.5.5
  * Fix: Some programs use "TotalTracks" tag, others the
    "TrackTotal". Now Flacon saves both.
  * Fix: Handling filenames with spaces in Makerfile.
* Fri Jan 28 2011 lazy.kent@opensuse.org
- Update to 0.5.4
  * Add: Polish translation. Thanks Tomasz Niedzielski.
  * The program saves "TotalTracks" tag now.
  * Some GUI performance optimisation.
* Fri Nov 26 2010 lazy.kent.suse@gmail.com
- Update to 0.5.3
  * Fix: The program safely handle "?" and "*" in the tags.
* Sun Nov 14 2010 lazy.kent.suse@gmail.com
- Remove buildroot in clean section.
* Mon Oct 25 2010 lazy.kent.suse@gmail.com
- Update to 0.5.2
  * Fix: Improved detection of the user language.
  * Fix: Error when user try to load a UTF-8 encoded cue file.
  * Fix: Sometimes pasting a new directory in the Directory field
    won't be respected.
* Tue Sep 21 2010 lazy.kent.suse@gmail.com
- Update to 0.5
  * Add: Program can process multiple disc at once.
  * Add: Download disc information from the CDDB.
  * Fix: Code refactoring and many bug fixes.
* Mon Aug 16 2010 lazy.kent.suse@gmail.com
- Update to 0.4.6
  * Add: Support WavPack output format. Thanks to Artem Aleksuk.
  * Add: Support True Audio (TTA) input format.
  * Add: Additional file checks and more informative messages.
* Sun Aug  8 2010 lazy.kent.suse@gmail.com
- Update to 0.4.5
  * Add: Czech translation.
  * Add: Now the program has the correct icons in the Gnome.
  * Add: Support for SVG icons.
  * Fix: Loading icons in the Gnome 2.30.
* Tue Jul 27 2010 lazy.kent.suse@gmail.com
- Update to 0.4.4
  * Fix: Incorrect processing of the tag "genre" in the resulting
    file name.
* Tue Jul 20 2010 lazy.kent.suse@gmail.com
- Update to 0.4.3
  * Fix: Some fixes in desktop file.
* Thu Jun 10 2010 lazy.kent.suse@gmail.com
- Update to 0.4.2
  * Fix: Now program compatible with the old versions of the PyQt.
  * Fix: Some small fixes in the translation.
* Fri May 28 2010 lazy.kent.suse@gmail.com
- Initial package created - 0.4.1
